@@ -1,11 +1,12 @@
+use 5.008;
 use strict;
 use warnings;
 package WWW::IP;
-$WWW::IP::VERSION = '0.03';
+$WWW::IP::VERSION = '0.04';
 use HTTP::Tiny;
-use 5.008;
 use WWW::hmaip ();
 use WWW::ipinfo ();
+use WWW::canihazip ();
 
 # ABSTRACT: Returns your ip address with failsafe mechanism
 
@@ -19,12 +20,16 @@ BEGIN {
 
 
 sub get_ip {
-  my $ip = eval { WWW::hmaip::get_ip() };
+  my $ip = eval { WWW::canihazip::get_ip() };
   if ($@)
   {
-    $ip = WWW::ipinfo::get_ipinfo->{ip};
+    $ip = eval { WWW::hmaip::get_ip() };
+    if ($@)
+    {
+      $ip = eval { WWW::ipinfo::get_ipinfo->{ip} };
+    }
   }
-  return $ip;
+  $ip;
 }
 
 
@@ -42,7 +47,7 @@ WWW::IP - Returns your ip address with failsafe mechanism
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -58,11 +63,8 @@ Exports the C<get_ip> function.
 
 =head2 get_ip
 
-Returns your ip address. Will try a number of services in succession should the 
-
-    use WWW::IP;
-
-    my $ip = get_ip();
+Returns your ip address. Will try a number of services in succession should the
+initial request fail
 
 =head1 SEE ALSO
 
@@ -72,6 +74,10 @@ These modules are used by WWW::IP:
 
 =item *
 
+L<WWW::canihazip> - a module that returns your ip address
+
+=item *
+
 L<WWW::ipinfo> - a module that returns ip address and geolocation data
 
 =item *
@@ -86,7 +92,7 @@ David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by David Farrell.
+This software is copyright (c) 2016 by David Farrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
